From a58ea7fa193c17d390c3acd1a0c94a9a918c944d Mon Sep 17 00:00:00 2001
From: henrikjust
Date: Mon, 22 Mar 2010 09:45:59 +0000
Subject: [PATCH] Writer2xhtml custom config ui + preparing for EPUB
git-svn-id: svn://svn.code.sf.net/p/writer2latex/code/trunk@54 f0f2a975-2e09-46c8-9428-3b39399b9f3c
---
source/distro/changelog.txt | 8 +-
.../filter/ConfigurationDialogBase.java | 384 ++++++++++++++++++
.../writer2xhtml/ConfigurationDialog.java | 194 +++++++++
.../da/comp/writer2xhtml/W2XRegistration.java | 14 +-
source/java/writer2latex/api/Config.java | 2 +-
.../java/writer2latex/api/ContentEntry.java | 61 +++
.../writer2latex/api/ConverterResult.java | 9 +-
source/java/writer2latex/api/MetaData.java | 45 ++
source/java/writer2latex/api/OutputFile.java | 11 +-
.../java/writer2latex/base/ConverterBase.java | 5 +-
.../ConverterResultImpl.java} | 82 ++--
.../writer2latex/bibtex/BibTeXDocument.java | 4 -
source/java/writer2latex/epub/Package.html | 13 +
.../writer2latex/latex/ConverterPalette.java | 2 +-
.../writer2latex/latex/LaTeXDocument.java | 10 +-
.../writer2latex/latex/SectionConverter.java | 5 +-
source/java/writer2latex/office/MetaData.java | 6 +-
.../xhtml/BatchConverterImpl.java | 4 +-
source/java/writer2latex/xhtml/Converter.java | 4 +-
.../writer2latex/xhtml/XhtmlDocument.java | 11 +-
.../xmerge/BinaryGraphicsDocument.java | 5 -
.../java/writer2latex/xmerge/DOMDocument.java | 6 +-
.../writer2latex/xmerge/OfficeDocument.java | 6 +-
source/oxt/writer2xhtml/OptionPages.xcu | 6 +-
.../oxt/writer2xhtml/W2XDialogs2/Content.xdl | 4 +-
.../oxt/writer2xhtml/W2XDialogs2/General.xdl | 2 +-
26 files changed, 783 insertions(+), 120 deletions(-)
create mode 100644 source/java/org/openoffice/da/comp/w2lcommon/filter/ConfigurationDialogBase.java
create mode 100644 source/java/org/openoffice/da/comp/writer2xhtml/ConfigurationDialog.java
create mode 100644 source/java/writer2latex/api/ContentEntry.java
create mode 100644 source/java/writer2latex/api/MetaData.java
rename source/java/writer2latex/{xmerge/ConvertData.java => base/ConverterResultImpl.java} (70%)
create mode 100644 source/java/writer2latex/epub/Package.html
diff --git a/source/distro/changelog.txt b/source/distro/changelog.txt
index a3eedfb..fa2ed47 100644
--- a/source/distro/changelog.txt
+++ b/source/distro/changelog.txt
@@ -2,8 +2,12 @@ Changelog for Writer2LaTeX version 1.0 -> 1.2
---------- version 1.1.2 ----------
-[all] API change: New methods getMIMEType() and getSequenceNumber() added
- to the OutputFile interface
+[all] API change: The interface ConverterResult supports additional methods
+ to access the main document flow as a List, an "external" table of contents
+ and meta data of the source document. New interfaces TocEntry and MetaData
+ have been introduced to support this.
+
+[all] API change: New method getMIMEType() added to the OutputFile interface
[w2x] Added user interface to edit custom configuration
diff --git a/source/java/org/openoffice/da/comp/w2lcommon/filter/ConfigurationDialogBase.java b/source/java/org/openoffice/da/comp/w2lcommon/filter/ConfigurationDialogBase.java
new file mode 100644
index 0000000..7b3ce23
--- /dev/null
+++ b/source/java/org/openoffice/da/comp/w2lcommon/filter/ConfigurationDialogBase.java
@@ -0,0 +1,384 @@
+/************************************************************************
+*
+* ConfigurationDialogBase.java
+*
+* This library is free software; you can redistribute it and/or
+* modify it under the terms of the GNU Lesser General Public
+* License version 2.1, as published by the Free Software Foundation.
+*
+* This library is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this library; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+* MA 02111-1307 USA
+*
+* Copyright: 2002-2010 by Henrik Just
+*
+* All Rights Reserved.
+*
+* Version 1.2 (2010-03-22)
+*
+*/
+
+package org.openoffice.da.comp.w2lcommon.filter;
+
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.text.Collator;
+import java.util.Arrays;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.Set;
+
+import com.sun.star.awt.XContainerWindowEventHandler;
+import com.sun.star.awt.XDialog;
+import com.sun.star.awt.XDialogProvider2;
+import com.sun.star.awt.XWindow;
+import com.sun.star.io.NotConnectedException;
+import com.sun.star.io.XInputStream;
+import com.sun.star.io.XOutputStream;
+import com.sun.star.lang.XMultiComponentFactory;
+import com.sun.star.ucb.CommandAbortedException;
+import com.sun.star.ucb.XSimpleFileAccess2;
+import com.sun.star.ui.dialogs.ExecutableDialogResults;
+import com.sun.star.uno.AnyConverter;
+import com.sun.star.uno.UnoRuntime;
+import com.sun.star.uno.XComponentContext;
+import com.sun.star.util.XStringSubstitution;
+
+import com.sun.star.lib.uno.helper.WeakBase;
+import com.sun.star.lib.uno.adapter.XInputStreamToInputStreamAdapter;
+import com.sun.star.lib.uno.adapter.XOutputStreamToOutputStreamAdapter;
+
+import writer2latex.api.Config;
+import writer2latex.api.ConverterFactory;
+
+import org.openoffice.da.comp.w2lcommon.helper.DialogAccess;
+import org.openoffice.da.comp.w2lcommon.helper.StyleNameProvider;
+
+/** This is a base implementation of a uno component which supports several option pages
+ * with a single XContainerWindowEventHandler
. The title of the dialogs
+ * are used to differentiate between the individual pages
+ */
+public abstract class ConfigurationDialogBase extends WeakBase implements XContainerWindowEventHandler {
+
+ // The full path to the configuration file we handle
+ private String sConfigFileName = null;
+
+ // The component context
+ protected XComponentContext xContext;
+
+ // UNO simple file access service
+ protected XSimpleFileAccess2 sfa2 = null;
+
+ // Access to display names of the styles in the current document
+ protected StyleNameProvider styleNameProvider = null;
+
+ // The configuration implementation
+ protected Config config;
+
+ // The individual page handlers (the subclass must populate this)
+ protected Map pageHandlers = new HashMap();
+
+ // The subclass must provide these:
+
+ // MIME type of the document type we configure
+ protected abstract String getMIMEType();
+
+ // The dialog library containing the "new" and "delete" dialogs
+ protected abstract String getDialogLibraryName();
+
+ // The file name used for persistent storage of the edited configuration
+ protected abstract String getConfigFileName();
+
+ /** Create a new ConfigurationDialogBase
*/
+ public ConfigurationDialogBase(XComponentContext xContext) {
+ this.xContext = xContext;
+
+ // Get the SimpleFileAccess service
+ try {
+ Object sfaObject = xContext.getServiceManager().createInstanceWithContext(
+ "com.sun.star.ucb.SimpleFileAccess", xContext);
+ sfa2 = (XSimpleFileAccess2) UnoRuntime.queryInterface(XSimpleFileAccess2.class, sfaObject);
+ }
+ catch (com.sun.star.uno.Exception e) {
+ // failed to get SimpleFileAccess service (should not happen)
+ }
+
+ // Create the config file name
+ XStringSubstitution xPathSub = null;
+ try {
+ Object psObject = xContext.getServiceManager().createInstanceWithContext(
+ "com.sun.star.util.PathSubstitution", xContext);
+ xPathSub = (XStringSubstitution) UnoRuntime.queryInterface(XStringSubstitution.class, psObject);
+ sConfigFileName = xPathSub.substituteVariables("$(user)/"+getConfigFileName(), false);
+ }
+ catch (com.sun.star.uno.Exception e) {
+ // failed to get PathSubstitution service (should not happen)
+ }
+
+ // Create the configuration
+ config = ConverterFactory.createConverter(getMIMEType()).getConfig();
+
+ // Get the style name provider
+ styleNameProvider = new StyleNameProvider(xContext);
+ }
+
+ // Implement XContainerWindowEventHandler
+ public boolean callHandlerMethod(XWindow xWindow, Object event, String sMethod)
+ throws com.sun.star.lang.WrappedTargetException {
+ XDialog xDialog = (XDialog)UnoRuntime.queryInterface(XDialog.class, xWindow);
+ String sTitle = xDialog.getTitle();
+
+ if (!pageHandlers.containsKey(sTitle)) {
+ throw new com.sun.star.lang.WrappedTargetException("Unknown dialog "+sTitle);
+ }
+
+ DialogAccess dlg = new DialogAccess(xDialog);
+
+ try {
+ if (sMethod.equals("external_event") ) {
+ return handleExternalEvent(dlg, sTitle, event);
+ }
+ }
+ catch (com.sun.star.uno.RuntimeException e) {
+ throw e;
+ }
+ catch (com.sun.star.uno.Exception e) {
+ throw new com.sun.star.lang.WrappedTargetException(sMethod, this, e);
+ }
+
+ return pageHandlers.get(sTitle).handleEvent(dlg, sMethod);
+ }
+
+ private boolean handleExternalEvent(DialogAccess dlg, String sTitle, Object aEventObject) throws com.sun.star.uno.Exception {
+ try {
+ String sMethod = AnyConverter.toString(aEventObject);
+ if (sMethod.equals("ok")) {
+ loadConfig(); // The file may have been changed by other pages, thus we reload
+ pageHandlers.get(sTitle).getControls(dlg);
+ saveConfig();
+ return true;
+ }
+ else if (sMethod.equals("back") || sMethod.equals("initialize")) {
+ loadConfig();
+ pageHandlers.get(sTitle).setControls(dlg);
+ return true;
+ }
+ }
+ catch (com.sun.star.lang.IllegalArgumentException e) {
+ throw new com.sun.star.lang.IllegalArgumentException(
+ "Method external_event requires a string in the event object argument.", this,(short) -1);
+ }
+ return false;
+ }
+
+ // Load the user configuration from file
+ private void loadConfig() {
+ if (sfa2!=null && sConfigFileName!=null) {
+ try {
+ XInputStream xIs = sfa2.openFileRead(sConfigFileName);
+ if (xIs!=null) {
+ InputStream is = new XInputStreamToInputStreamAdapter(xIs);
+ config.read(is);
+ is.close();
+ xIs.closeInput();
+ }
+ }
+ catch (IOException e) {
+ // ignore
+ }
+ catch (NotConnectedException e) {
+ // ignore
+ }
+ catch (CommandAbortedException e) {
+ // ignore
+ }
+ catch (com.sun.star.uno.Exception e) {
+ // ignore
+ }
+ }
+ }
+
+ // Save the user configuration
+ private void saveConfig() {
+ if (sfa2!=null && sConfigFileName!=null) {
+ try {
+ //Remove the file if it exists
+ if (sfa2.exists(sConfigFileName)) {
+ sfa2.kill(sConfigFileName);
+ }
+ // Then write the new contents
+ XOutputStream xOs = sfa2.openFileWrite(sConfigFileName);
+ if (xOs!=null) {
+ OutputStream os = new XOutputStreamToOutputStreamAdapter(xOs);
+ config.write(os);
+ os.close();
+ xOs.closeOutput();
+ }
+ }
+ catch (IOException e) {
+ // ignore
+ }
+ catch (NotConnectedException e) {
+ // ignore
+ }
+ catch (CommandAbortedException e) {
+ // ignore
+ }
+ catch (com.sun.star.uno.Exception e) {
+ // ignore
+ }
+ }
+ }
+
+ // Inner class to handle the individual option pages
+ protected abstract class PageHandler {
+ protected abstract void getControls(DialogAccess dlg);
+
+ protected abstract void setControls(DialogAccess dlg);
+
+ protected abstract boolean handleEvent(DialogAccess dlg, String sMethodName);
+
+ // Methods to handle user controlled lists
+ protected XDialog getDialog(String sDialogName) {
+ XMultiComponentFactory xMCF = xContext.getServiceManager();
+ try {
+ Object provider = xMCF.createInstanceWithContext(
+ "com.sun.star.awt.DialogProvider2", xContext);
+ XDialogProvider2 xDialogProvider = (XDialogProvider2)
+ UnoRuntime.queryInterface(XDialogProvider2.class, provider);
+ String sDialogUrl = "vnd.sun.star.script:"+sDialogName+"?location=application";
+ return xDialogProvider.createDialog(sDialogUrl);
+ }
+ catch (Exception e) {
+ return null;
+ }
+ }
+
+ private boolean deleteItem(String sName) {
+ XDialog xDialog=getDialog(getDialogLibraryName()+".DeleteDialog");
+ if (xDialog!=null) {
+ DialogAccess ddlg = new DialogAccess(xDialog);
+ String sLabel = ddlg.getLabelText("DeleteLabel");
+ sLabel = sLabel.replaceAll("%s", sName);
+ ddlg.setLabelText("DeleteLabel", sLabel);
+ boolean bDelete = xDialog.execute()==ExecutableDialogResults.OK;
+ xDialog.endExecute();
+ return bDelete;
+ }
+ return false;
+ }
+
+ private boolean deleteCurrentItem(DialogAccess dlg, String sListName) {
+ String[] sItems = dlg.getListBoxStringItemList(sListName);
+ short nSelected = dlg.getListBoxSelectedItem(sListName);
+ if (nSelected>=0 && deleteItem(sItems[nSelected])) {
+ int nOldLen = sItems.length;
+ String[] sNewItems = new String[nOldLen-1];
+ if (nSelected>0) {
+ System.arraycopy(sItems, 0, sNewItems, 0, nSelected);
+ }
+ if (nSelected suggestions) {
+ XDialog xDialog=getDialog(getDialogLibraryName()+".NewDialog");
+ if (xDialog!=null) {
+ int nCount = suggestions.size();
+ String[] sItems = new String[nCount];
+ int i=0;
+ for (String s : suggestions) {
+ sItems[i++] = s;
+ }
+ sortStringArray(sItems);
+ DialogAccess ndlg = new DialogAccess(xDialog);
+ ndlg.setListBoxStringItemList("Name", sItems);
+ String sResult = null;
+ if (xDialog.execute()==ExecutableDialogResults.OK) {
+ DialogAccess dlg = new DialogAccess(xDialog);
+ sResult = dlg.getTextFieldText("Name");
+ }
+ xDialog.endExecute();
+ return sResult;
+ }
+ return null;
+ }
+
+ private String appendItem(DialogAccess dlg, String sListName, Set suggestions) {
+ String[] sItems = dlg.getListBoxStringItemList(sListName);
+ String sNewItem = newItem(suggestions);
+ if (sNewItem!=null) {
+ int nOldLen = sItems.length;
+ for (short i=0; iConfigurationDialog */
+ public ConfigurationDialog(XComponentContext xContext) {
+ super(xContext);
+
+ pageHandlers.put("General", new GeneralHandler());
+ //pageHandlers.put("Template", new TemplateHandler());
+ pageHandlers.put("Formatting", new FormattingHandler());
+ //pageHandlers.put("StylesPartI", new StylesPartIHandler());
+ //pageHandlers.put("StylesPartII", new StylesPartIIHandler());
+ pageHandlers.put("Content", new ContentHandler());
+ }
+
+ // Implement remaining method from XContainerWindowEventHandler
+ public String[] getSupportedMethodNames() {
+ String[] sNames = { "EncodingChange" };
+ return sNames;
+ }
+
+ // the page handlers
+
+ private class GeneralHandler extends PageHandler {
+ private final String[] sEncodingValues = { "UTF-8", "UTF-16", "ISO-8859-1", "US-ASCII" };
+
+ @Override protected void setControls(DialogAccess dlg) {
+ checkBoxFromConfig(dlg, "NoDoctype", "no_doctype");
+ checkBoxFromConfig(dlg, "AddBOM", "add_bom");
+ listBoxFromConfig(dlg, "Encoding", "encoding", sEncodingValues, (short) 0);
+
+ if ("true".equals(config.getOption("hexadecimal_entities"))) {
+ dlg.setListBoxSelectedItem("HexadecimalEntities", (short) 0);
+ }
+ else {
+ dlg.setListBoxSelectedItem("HexadecimalEntities", (short) 1);
+ }
+
+ checkBoxFromConfig(dlg, "UseNamedEntities", "use_named_entities");
+ checkBoxFromConfig(dlg, "Multilingual", "multilingual");
+ checkBoxFromConfig(dlg, "PrettyPrint", "pretty_print");
+
+ updateControls(dlg);
+ }
+
+ @Override protected void getControls(DialogAccess dlg) {
+ checkBoxToConfig(dlg, "NoDoctype", "no_doctype");
+ checkBoxToConfig(dlg, "AddBOM", "add_bom");
+ listBoxToConfig(dlg, "Encoding", "encoding", sEncodingValues);
+
+ config.setOption("hexadecimal_entities", Boolean.toString(dlg.getListBoxSelectedItem("HexadecimalEntities")==(short)0));
+
+ checkBoxToConfig(dlg, "UseNamedEntities", "use_named_entities");
+ checkBoxToConfig(dlg, "Multilingual", "multilingual");
+ checkBoxToConfig(dlg, "PrettyPrint", "pretty_print");
+ }
+
+ @Override protected boolean handleEvent(DialogAccess dlg, String sMethod) {
+ if (sMethod.equals("EncodingChange")) {
+ updateControls(dlg);
+ return true;
+ }
+ return false;
+ }
+
+ private void updateControls(DialogAccess dlg) {
+ boolean bUnicode = dlg.getListBoxSelectedItem("Encoding")<2;
+ dlg.setControlEnabled("HexadecimalEntitiesLabel", !bUnicode);
+ dlg.setControlEnabled("HexadecimalEntities", !bUnicode);
+ }
+
+ }
+
+ private class FormattingHandler extends PageHandler {
+ private final String[] sExportValues = { "convert_all", "ignore_styles", "ignore_hard", "ignore_all" };
+
+ @Override protected void setControls(DialogAccess dlg) {
+ listBoxFromConfig(dlg, "Formatting", "formatting", sExportValues, (short) 0);
+ listBoxFromConfig(dlg, "FrameFormatting", "frame_formatting", sExportValues, (short) 0);
+
+ // OOo does not support styles for sections and tables, hence this simplified variant
+ dlg.setCheckBoxStateAsBoolean("SectionFormatting",
+ config.getOption("section_formatting").equals("convert_all") ||
+ config.getOption("section_formatting").equals("ignore_styles"));
+ dlg.setCheckBoxStateAsBoolean("TableFormatting",
+ config.getOption("table_formatting").equals("convert_all") ||
+ config.getOption("table_formatting").equals("ignore_styles"));
+
+ checkBoxFromConfig(dlg, "IgnoreTableDimensions", "ignore_table_dimensions");
+ checkBoxFromConfig(dlg, "UseListHack", "use_list_hack");
+ checkBoxFromConfig(dlg, "ConvertToPx", "convert_to_px");
+ checkBoxFromConfig(dlg, "SeparateStylesheet", "separate_stylesheet");
+ }
+
+ @Override protected void getControls(DialogAccess dlg) {
+ listBoxToConfig(dlg, "Formatting", "formatting", sExportValues);
+ listBoxToConfig(dlg, "FrameFormatting", "frame_formatting", sExportValues);
+
+ config.setOption("section_formatting", dlg.getCheckBoxStateAsBoolean("SectionFormatting") ? "convert_all" : "ignore_all");
+ config.setOption("table_formatting", dlg.getCheckBoxStateAsBoolean("TableFormatting") ? "convert_all" : "ignore_all");
+
+ checkBoxToConfig(dlg, "IgnoreTableDimensions", "ignore_table_dimensions");
+ checkBoxToConfig(dlg, "UseListHack", "use_list_hack");
+ checkBoxToConfig(dlg, "ConvertToPx", "convert_to_px");
+ checkBoxToConfig(dlg, "SeparateStylesheet", "separate_stylesheet");
+ }
+
+ @Override protected boolean handleEvent(DialogAccess dlg, String sMethod) {
+ return false;
+ }
+
+ }
+
+ private class ContentHandler extends PageHandler {
+ private final String[] sFormulaValues = { "image+starmath", "image+latex", "starmath", "latex" };
+
+ @Override protected void setControls(DialogAccess dlg) {
+ listBoxFromConfig(dlg, "Formulas", "formulas", sFormulaValues, (short) 0);
+ }
+
+ @Override protected void getControls(DialogAccess dlg) {
+ listBoxToConfig(dlg, "Formulas", "formulas", sFormulaValues);
+ }
+
+ @Override protected boolean handleEvent(DialogAccess dlg, String sMethod) {
+ return false;
+ }
+
+ }
+
+
+}
diff --git a/source/java/org/openoffice/da/comp/writer2xhtml/W2XRegistration.java b/source/java/org/openoffice/da/comp/writer2xhtml/W2XRegistration.java
index 23efa86..2e639ab 100644
--- a/source/java/org/openoffice/da/comp/writer2xhtml/W2XRegistration.java
+++ b/source/java/org/openoffice/da/comp/writer2xhtml/W2XRegistration.java
@@ -16,11 +16,11 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston,
* MA 02111-1307 USA
*
- * Copyright: 2002-2008 by Henrik Just
+ * Copyright: 2002-2010 by Henrik Just
*
* All Rights Reserved.
*
- * Version 1.0 (2008-10-04)
+ * Version 1.2 (2010-03-22)
*
*/
@@ -90,6 +90,12 @@ public class W2XRegistration {
multiFactory,
regKey);
}
+ else if (implName.equals(ConfigurationDialog.__implementationName)) {
+ xSingleServiceFactory = FactoryHelper.getServiceFactory(ConfigurationDialog.class,
+ ConfigurationDialog.__serviceName,
+ multiFactory,
+ regKey);
+ }
return xSingleServiceFactory;
}
@@ -113,7 +119,9 @@ public class W2XRegistration {
FactoryHelper.writeRegistryServiceInfo(XhtmlOptionsDialogXsl.__implementationName,
XhtmlOptionsDialogXsl.__serviceName, regKey) &
FactoryHelper.writeRegistryServiceInfo(XhtmlOptionsDialogCalc.__implementationName,
- XhtmlOptionsDialogCalc.__serviceName, regKey);
+ XhtmlOptionsDialogCalc.__serviceName, regKey) &
+ FactoryHelper.writeRegistryServiceInfo(ConfigurationDialog.__implementationName,
+ ConfigurationDialog.__serviceName, regKey);
}
}
diff --git a/source/java/writer2latex/api/Config.java b/source/java/writer2latex/api/Config.java
index fa312d7..fc385ba 100644
--- a/source/java/writer2latex/api/Config.java
+++ b/source/java/writer2latex/api/Config.java
@@ -98,7 +98,7 @@ public interface Config {
/** Get a complex option
*
* @param sName the name of the complex option
- * @return
+ * @return the option
*/
public ComplexOption getComplexOption(String sName);
diff --git a/source/java/writer2latex/api/ContentEntry.java b/source/java/writer2latex/api/ContentEntry.java
new file mode 100644
index 0000000..5b6c9be
--- /dev/null
+++ b/source/java/writer2latex/api/ContentEntry.java
@@ -0,0 +1,61 @@
+/************************************************************************
+ *
+ * ContentEntry.java
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License version 2.1, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+ * MA 02111-1307 USA
+ *
+ * Copyright: 2002-2010 by Henrik Just
+ *
+ * All Rights Reserved.
+ *
+ * Version 1.2 (2010-03-15)
+ *
+ */
+
+package writer2latex.api;
+
+/** This interface represents a content entry, that is a named reference
+ * to a position within the output document.
+ */
+public interface ContentEntry {
+ /** Get the outline level of this ContentEntry
.
+ * The top level is 1 (entries corresponding to indexes are considered
+ * top level).
+ * Note that intermediate levels may be missing (e.g. a heading of
+ * level 3 may follow immediately after a heading of level 1).
+ *
+ * @return the outline level
+ */
+ public int getLevel();
+
+ /** Get the title for this entry
+ *
+ * @return the title
+ */
+ public String getTitle();
+
+ /** Get the file associated with the entry
+ *
+ * @return the output file
+ */
+ public OutputFile getFile();
+
+ /** Get the name of a target within the file, if any
+ *
+ * @return the target name, or null if no target is needed
+ */
+ public String getTarget();
+
+}
diff --git a/source/java/writer2latex/api/ConverterResult.java b/source/java/writer2latex/api/ConverterResult.java
index 69528c5..d9ab539 100644
--- a/source/java/writer2latex/api/ConverterResult.java
+++ b/source/java/writer2latex/api/ConverterResult.java
@@ -16,11 +16,11 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston,
* MA 02111-1307 USA
*
- * Copyright: 2002-2008 by Henrik Just
+ * Copyright: 2002-2010 by Henrik Just
*
* All Rights Reserved.
*
- * Version 1.0 (2008-11-24)
+ * Version 1.2 (2010-03-16)
*
*/
@@ -46,6 +46,11 @@ public interface ConverterResult {
*/
public Iterator iterator();
+ /** Get the meta data associated with the source document
+ * @return the meta data
+ */
+ public MetaData getMetaData();
+
/** Write all files of the ConverterResult
to a directory.
* Subdirectories are created as required by the individual
* OutputFile
s.
diff --git a/source/java/writer2latex/api/MetaData.java b/source/java/writer2latex/api/MetaData.java
new file mode 100644
index 0000000..ddb64be
--- /dev/null
+++ b/source/java/writer2latex/api/MetaData.java
@@ -0,0 +1,45 @@
+/************************************************************************
+ *
+ * MetaData.java
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License version 2.1, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+ * MA 02111-1307 USA
+ *
+ * Copyright: 2002-2010 by Henrik Just
+ *
+ * All Rights Reserved.
+ *
+ * Version 1.2 (2010-03-15)
+ *
+ */
+
+package writer2latex.api;
+
+/** This interface provides access to the predefined meta data of the
+ * source document (currently incomplete)
+ */
+public interface MetaData {
+ /** Get the title of the source document
+ *
+ * @return the title (may return an empty string)
+ */
+ public String getTitle();
+
+ /** Get the (main) language of the document
+ *
+ * @return the language
+ */
+ public String getLanguage();
+
+}
diff --git a/source/java/writer2latex/api/OutputFile.java b/source/java/writer2latex/api/OutputFile.java
index 08b1cd7..b008a8c 100644
--- a/source/java/writer2latex/api/OutputFile.java
+++ b/source/java/writer2latex/api/OutputFile.java
@@ -52,17 +52,8 @@ public interface OutputFile {
/** Get the MIME type of the OutputFile
.
*
- * @return string reprensentation of the MIME type
+ * @return string representation of the MIME type
*/
public String getMIMEType();
- /** Get the sequence number of this OutputFile
.
- * The master document has the sequence number 0.
- * Other files which are part of the main document flow has a unique, positive sequence number.
- * Auxiliary files like images always has the sequence number -1.
- *
- * @return the sequence number
- */
- public int getSequenceNumber();
-
}
diff --git a/source/java/writer2latex/base/ConverterBase.java b/source/java/writer2latex/base/ConverterBase.java
index 073d5d3..3d0ff68 100644
--- a/source/java/writer2latex/base/ConverterBase.java
+++ b/source/java/writer2latex/base/ConverterBase.java
@@ -40,7 +40,6 @@ import writer2latex.office.ImageLoader;
import writer2latex.office.MetaData;
import writer2latex.office.OfficeReader;
import writer2latex.xmerge.EmbeddedObject;
-import writer2latex.xmerge.ConvertData;
import writer2latex.xmerge.OfficeDocument;
/**Abstract base implementation of writer2latex.api.Converter
@@ -58,12 +57,12 @@ public abstract class ConverterBase implements Converter {
// The output file(s)
protected String sTargetFileName;
- protected ConvertData convertData;
+ protected ConverterResultImpl convertData;
// Constructor
public ConverterBase() {
graphicConverter = null;
- convertData = new ConvertData();
+ convertData = new ConverterResultImpl();
}
// Implement the interface
diff --git a/source/java/writer2latex/bibtex/BibTeXDocument.java b/source/java/writer2latex/bibtex/BibTeXDocument.java
index 5e9270d..b3acecc 100644
--- a/source/java/writer2latex/bibtex/BibTeXDocument.java
+++ b/source/java/writer2latex/bibtex/BibTeXDocument.java
@@ -106,10 +106,6 @@ public class BibTeXDocument implements Document {
return MIMETypes.BIBTEX;
}
- public int getSequenceNumber() {
- return -1;
- }
-
/**
* Writes out the Document
content to the specified
* OutputStream
.
diff --git a/source/java/writer2latex/epub/Package.html b/source/java/writer2latex/epub/Package.html
new file mode 100644
index 0000000..68c2682
--- /dev/null
+++ b/source/java/writer2latex/epub/Package.html
@@ -0,0 +1,13 @@
+
+
+
+
+ The package writer2latex.epub
+
+
+
+This package contains EPUB specific code.
+It contains a writerlatex.api.Converter
implementation for
+conversion into EPUB.
+
+
diff --git a/source/java/writer2latex/latex/ConverterPalette.java b/source/java/writer2latex/latex/ConverterPalette.java
index 2eb8921..3f8a302 100644
--- a/source/java/writer2latex/latex/ConverterPalette.java
+++ b/source/java/writer2latex/latex/ConverterPalette.java
@@ -174,7 +174,7 @@ public final class ConverterPalette extends ConverterBase {
info = new Info(ofr,config,this);
// Create master document and add this
- this.texDoc = new LaTeXDocument(sTargetFileName,config.getWrapLinesAfter(),0);
+ this.texDoc = new LaTeXDocument(sTargetFileName,config.getWrapLinesAfter());
if (config.getBackend()!=LaTeXConfig.XETEX) {
texDoc.setEncoding(ClassicI18n.writeJavaEncoding(config.getInputencoding()));
}
diff --git a/source/java/writer2latex/latex/LaTeXDocument.java b/source/java/writer2latex/latex/LaTeXDocument.java
index ffedf73..cf55b59 100644
--- a/source/java/writer2latex/latex/LaTeXDocument.java
+++ b/source/java/writer2latex/latex/LaTeXDocument.java
@@ -49,8 +49,6 @@ public class LaTeXDocument implements Document {
private LaTeXDocumentPortion contents;
- private int nSequenceNumber = -1;
-
/**
* Constructs a new LaTeX Document.
*
@@ -59,12 +57,10 @@ public class LaTeXDocument implements Document {
*
* @param sName The name of the LaTeXDocument
.
* @param nWrap Lines should be wrapped after this position
- * @param nSequenceNumber this file has this sequence number in the result
*/
- public LaTeXDocument(String sName,int nWrap, int nSequenceNumber) {
+ public LaTeXDocument(String sName,int nWrap) {
this.nWrap = nWrap;
this.sName = trimDocumentName(sName);
- this.nSequenceNumber = nSequenceNumber;
contents = new LaTeXDocumentPortion(true);
}
@@ -104,10 +100,6 @@ public class LaTeXDocument implements Document {
return MIMETypes.LATEX;
}
- public int getSequenceNumber() {
- return nSequenceNumber;
- }
-
/**
* Writes out the Document
content to the specified
* OutputStream
.
diff --git a/source/java/writer2latex/latex/SectionConverter.java b/source/java/writer2latex/latex/SectionConverter.java
index 6c8d1f2..3fff3c6 100644
--- a/source/java/writer2latex/latex/SectionConverter.java
+++ b/source/java/writer2latex/latex/SectionConverter.java
@@ -46,9 +46,6 @@ public class SectionConverter extends ConverterHelper {
// Filenames for external sections
private ExportNameCollection fileNames = new ExportNameCollection(true);
- // Current sequence number (until this class creates further LaTeX files, the master file is the only document)
- private int nSequenceNumber = 0;
-
/** Constructs a new SectionStyleConverter
.
*/
public SectionConverter(OfficeReader ofr, LaTeXConfig config,
@@ -83,7 +80,7 @@ public class SectionConverter extends ConverterHelper {
LaTeXDocumentPortion sectionLdp = ldp;
if (sFileName!=null) {
- LaTeXDocument newDoc = new LaTeXDocument(sFileName,config.getWrapLinesAfter(),++nSequenceNumber);
+ LaTeXDocument newDoc = new LaTeXDocument(sFileName,config.getWrapLinesAfter());
if (config.getBackend()!=LaTeXConfig.XETEX) {
newDoc.setEncoding(ClassicI18n.writeJavaEncoding(config.getInputencoding()));
}
diff --git a/source/java/writer2latex/office/MetaData.java b/source/java/writer2latex/office/MetaData.java
index 2c72fa3..052c8b5 100644
--- a/source/java/writer2latex/office/MetaData.java
+++ b/source/java/writer2latex/office/MetaData.java
@@ -16,11 +16,11 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston,
* MA 02111-1307 USA
*
- * Copyright: 2002-2008 by Henrik Just
+ * Copyright: 2002-2010 by Henrik Just
*
* All Rights Reserved.
*
- * Version 1.0 (2008-11-23)
+ * Version 1.2 (2010-03-15)
*
*/
@@ -38,7 +38,7 @@ import writer2latex.xmerge.OfficeDocument;
/**
* This class represents the metadata of an OOo Writer document.
*/
-public class MetaData {
+public class MetaData implements writer2latex.api.MetaData {
// Dublin Core
private String sTitle = "";
private String sCreator = "";
diff --git a/source/java/writer2latex/xhtml/BatchConverterImpl.java b/source/java/writer2latex/xhtml/BatchConverterImpl.java
index be713a4..a1424a9 100644
--- a/source/java/writer2latex/xhtml/BatchConverterImpl.java
+++ b/source/java/writer2latex/xhtml/BatchConverterImpl.java
@@ -69,7 +69,7 @@ public class BatchConverterImpl extends BatchConverterBase {
}
public void readTemplate(InputStream is) throws IOException {
- template = new XhtmlDocument("Template",XhtmlDocument.XHTML10,-1);
+ template = new XhtmlDocument("Template",XhtmlDocument.XHTML10);
try {
template.read(is);
}
@@ -89,7 +89,7 @@ public class BatchConverterImpl extends BatchConverterBase {
public OutputFile createIndexFile(String sHeading, IndexPageEntry[] entries) {
// Create the index page (with header/footer or from template)
- XhtmlDocument htmlDoc = new XhtmlDocument("index",XhtmlDocument.XHTML10,0);
+ XhtmlDocument htmlDoc = new XhtmlDocument("index",XhtmlDocument.XHTML10);
htmlDoc.setConfig(config);
if (template!=null) { htmlDoc.readFromTemplate(template); }
else { htmlDoc.createHeaderFooter(); }
diff --git a/source/java/writer2latex/xhtml/Converter.java b/source/java/writer2latex/xhtml/Converter.java
index ee7cc71..59bbaff 100644
--- a/source/java/writer2latex/xhtml/Converter.java
+++ b/source/java/writer2latex/xhtml/Converter.java
@@ -102,7 +102,7 @@ public class Converter extends ConverterBase {
// override
public void readTemplate(InputStream is) throws IOException {
- template = new XhtmlDocument("Template",nType,-1);
+ template = new XhtmlDocument("Template",nType);
template.read(is);
}
@@ -441,7 +441,7 @@ public class Converter extends ConverterBase {
// Prepare next output file
public Element nextOutFile() {
if (nOutFileIndex>=0) { textCv.insertFootnotes(htmlDoc.getContentNode()); }
- htmlDoc = new XhtmlDocument(getOutFileName(++nOutFileIndex,false),nType,nOutFileIndex);
+ htmlDoc = new XhtmlDocument(getOutFileName(++nOutFileIndex,false),nType);
htmlDoc.setConfig(config);
if (template!=null) { htmlDoc.readFromTemplate(template); }
else if (bNeedHeaderFooter) { htmlDoc.createHeaderFooter(); }
diff --git a/source/java/writer2latex/xhtml/XhtmlDocument.java b/source/java/writer2latex/xhtml/XhtmlDocument.java
index 5dcbc69..538487f 100644
--- a/source/java/writer2latex/xhtml/XhtmlDocument.java
+++ b/source/java/writer2latex/xhtml/XhtmlDocument.java
@@ -79,9 +79,6 @@ public class XhtmlDocument extends DOMDocument {
// Type of document
private int nType;
- // Sequence number
- private int nSequenceNumber;
-
// Configuration
private String sEncoding = "UTF-8";
private boolean bUseNamedEntities = false;
@@ -115,12 +112,10 @@ public class XhtmlDocument extends DOMDocument {
* writer2latex.xmerge.DOMDocument.
* @param name Document
name.
* @param nType the type of document
- * @param nSequenceNumber the sequence number of this file in the export
*/
- public XhtmlDocument(String name, int nType, int nSequenceNumber) {
+ public XhtmlDocument(String name, int nType) {
super(name,sExtension[nType]);
this.nType = nType;
- this.nSequenceNumber = nSequenceNumber;
// Define publicId and systemId
String sPublicId = null;
String sSystemId = null;
@@ -178,10 +173,6 @@ public class XhtmlDocument extends DOMDocument {
return "";
}
- @Override public int getSequenceNumber() {
- return nSequenceNumber;
- }
-
public Element getHeadNode() { return headNode; }
public Element getBodyNode() { return bodyNode; }
diff --git a/source/java/writer2latex/xmerge/BinaryGraphicsDocument.java b/source/java/writer2latex/xmerge/BinaryGraphicsDocument.java
index f4c7756..b30bf1d 100644
--- a/source/java/writer2latex/xmerge/BinaryGraphicsDocument.java
+++ b/source/java/writer2latex/xmerge/BinaryGraphicsDocument.java
@@ -166,10 +166,5 @@ public class BinaryGraphicsDocument implements Document {
public String getMIMEType() {
return sMimeType;
}
-
-
- public int getSequenceNumber() {
- return -1;
- }
}
\ No newline at end of file
diff --git a/source/java/writer2latex/xmerge/DOMDocument.java b/source/java/writer2latex/xmerge/DOMDocument.java
index 060914e..e235e23 100644
--- a/source/java/writer2latex/xmerge/DOMDocument.java
+++ b/source/java/writer2latex/xmerge/DOMDocument.java
@@ -393,15 +393,11 @@ public class DOMDocument
return doc;
}
- // TODO: We need these because we implement OutputFile (don't do that..)
+ // We need this because we implement OutputFile
public String getMIMEType() {
return "";
}
- public int getSequenceNumber() {
- return -1;
- }
-
}
diff --git a/source/java/writer2latex/xmerge/OfficeDocument.java b/source/java/writer2latex/xmerge/OfficeDocument.java
index 09ce812..179249f 100644
--- a/source/java/writer2latex/xmerge/OfficeDocument.java
+++ b/source/java/writer2latex/xmerge/OfficeDocument.java
@@ -101,7 +101,7 @@ public class OfficeDocument
/** DOM Document
of content.xml. */
private Document styleDoc = null;
- /** DOM Docuemtn
of META-INF/manifest.xml. */
+ /** DOM Document
of META-INF/manifest.xml. */
private Document manifestDoc = null;
private String documentName = null;
@@ -1288,9 +1288,5 @@ public class OfficeDocument
return "";
}
-
- public int getSequenceNumber() {
- return -1;
- }
}
diff --git a/source/oxt/writer2xhtml/OptionPages.xcu b/source/oxt/writer2xhtml/OptionPages.xcu
index ad45cac..a36ec1a 100644
--- a/source/oxt/writer2xhtml/OptionPages.xcu
+++ b/source/oxt/writer2xhtml/OptionPages.xcu
@@ -55,7 +55,7 @@
%origin%/W2XDialogs2/General.xdl
-
+ org.openoffice.da.writer2xhtml.ConfigurationDialog
@@ -99,7 +99,7 @@
%origin%/W2XDialogs2/Formatting.xdl
-
+ org.openoffice.da.writer2xhtml.ConfigurationDialog
@@ -165,7 +165,7 @@
%origin%/W2XDialogs2/Content.xdl
-
+ org.openoffice.da.writer2xhtml.ConfigurationDialog
diff --git a/source/oxt/writer2xhtml/W2XDialogs2/Content.xdl b/source/oxt/writer2xhtml/W2XDialogs2/Content.xdl
index 11be1d6..9d1594e 100644
--- a/source/oxt/writer2xhtml/W2XDialogs2/Content.xdl
+++ b/source/oxt/writer2xhtml/W2XDialogs2/Content.xdl
@@ -1,10 +1,10 @@
-
+
-
+
diff --git a/source/oxt/writer2xhtml/W2XDialogs2/General.xdl b/source/oxt/writer2xhtml/W2XDialogs2/General.xdl
index fd76384..d00afe5 100644
--- a/source/oxt/writer2xhtml/W2XDialogs2/General.xdl
+++ b/source/oxt/writer2xhtml/W2XDialogs2/General.xdl
@@ -23,6 +23,6 @@
-
+
\ No newline at end of file
diff --git a/source/java/writer2latex/xmerge/ConvertData.java b/source/java/writer2latex/base/ConverterResultImpl.java
similarity index 70%
rename from source/java/writer2latex/xmerge/ConvertData.java
rename to source/java/writer2latex/base/ConverterResultImpl.java
index 34c702b..95a5b6e 100644
--- a/source/java/writer2latex/xmerge/ConvertData.java
+++ b/source/java/writer2latex/base/ConverterResultImpl.java
@@ -1,46 +1,30 @@
/************************************************************************
- *
- * The Contents of this file are made available subject to the terms of
- *
- * - GNU Lesser General Public License Version 2.1
- *
- * Sun Microsystems Inc., October, 2000
- *
- * GNU Lesser General Public License Version 2.1
- * =============================================
- * Copyright 2000 by Sun Microsystems, Inc.
- * 901 San Antonio Road, Palo Alto, CA 94303, USA
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License version 2.1, as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA 02111-1307 USA
- *
- * The Initial Developer of the Original Code is: Sun Microsystems, Inc.
- *
- * Copyright: 2000 by Sun Microsystems, Inc.
- *
- * All Rights Reserved.
- *
- * Contributor(s): _______________________________________
- *
- *
- ************************************************************************/
-
-// This version is adapted for Writer2LaTeX
-// Change: The first document added will become the "master document" 2006/10/05
-// Version 1.0 (2008-11-24)
+*
+* ConverterResultImpl.java
+*
+* This library is free software; you can redistribute it and/or
+* modify it under the terms of the GNU Lesser General Public
+* License version 2.1, as published by the Free Software Foundation.
+*
+* This library is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this library; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+* MA 02111-1307 USA
+*
+* Copyright: 2002-2010 by Henrik Just
+*
+* All Rights Reserved.
+*
+* Version 1.2 (2010-03-22)
+*
+*/
-package writer2latex.xmerge;
+package writer2latex.base;
import java.io.File;
import java.io.FileOutputStream;
@@ -49,6 +33,7 @@ import java.util.Vector;
import java.util.Iterator;
import writer2latex.api.ConverterResult;
+import writer2latex.api.MetaData;
import writer2latex.api.OutputFile;
/**
@@ -58,9 +43,10 @@ import writer2latex.api.OutputFile;
* name and a Vector
of OutputFile
objects.
*
* @author Martin Maher
+ * TODO: Rewrite to support extended API
*/
-public class ConvertData implements ConverterResult {
-
+public class ConverterResultImpl implements ConverterResult {
+
/**
* Vector of OutputFile
objects.
*/
@@ -74,6 +60,8 @@ public class ConvertData implements ConverterResult {
*/
private String name;
+ private MetaData metaData = null;
+
/**
* Resets ConvertData. This empties all OutputFile
@@ -141,6 +129,14 @@ public class ConvertData implements ConverterResult {
return v.iterator();
}
+ public MetaData getMetaData() {
+ return metaData;
+ }
+
+ public void setMetaData(MetaData metaData) {
+ this.metaData = metaData;
+ }
+
/**
* Gets the number of OutputFile
objects currently stored